@@ -470,8 +470,9 @@ static fsal_status_t read_dirents(struct fsal_obj_handle *dir_hdl,
 	int bpos, nread;
 	struct dirent64 *dentry;
 	char buf[BUF_SIZE];
-	struct gpfs_fsal_export *exp = container_of(
-		op_ctx->fsal_export, struct gpfs_fsal_export, export);
+	struct gpfs_fsal_export *exp = container_of(op_ctx->fsal_export,
+						    struct gpfs_fsal_export,
+						    export);
 	int export_fd = exp->export_fd;
 
 	if (whence != NULL)
@@ -553,13 +554,15 @@ done:
 	return fsalstat(fsal_error, retval);
 }
 
-static fsal_status_t
-renamefile(struct fsal_obj_handle *obj_hdl, struct fsal_obj_handle *olddir_hdl,
-	   const char *old_name, struct fsal_obj_handle *newdir_hdl,
-	   const char *new_name, struct fsal_attrlist *olddir_pre_attrs_out,
-	   struct fsal_attrlist *olddir_post_attrs_out,
-	   struct fsal_attrlist *newdir_pre_attrs_out,
-	   struct fsal_attrlist *newdir_post_attrs_out)
+static fsal_status_t renamefile(struct fsal_obj_handle *obj_hdl,
+				struct fsal_obj_handle *olddir_hdl,
+				const char *old_name,
+				struct fsal_obj_handle *newdir_hdl,
+				const char *new_name,
+				struct fsal_attrlist *olddir_pre_attrs_out,
+				struct fsal_attrlist *olddir_post_attrs_out,
+				struct fsal_attrlist *newdir_pre_attrs_out,
+				struct fsal_attrlist *newdir_post_attrs_out)
 {
 	fsal_status_t status;
 
@@ -620,8 +623,9 @@ static fsal_status_t getxattrs(struct fsal_obj_handle *obj_hdl,
 	int errsv;
 	struct getxattr_arg gxarg;
 	struct gpfs_fsal_obj_handle *myself;
-	struct gpfs_fsal_export *exp = container_of(
-		op_ctx->fsal_export, struct gpfs_fsal_export, export);
+	struct gpfs_fsal_export *exp = container_of(op_ctx->fsal_export,
+						    struct gpfs_fsal_export,
+						    export);
 	int export_fd = exp->export_fd;
 
 	myself = container_of(obj_hdl, struct gpfs_fsal_obj_handle, obj_handle);
@@ -664,8 +668,9 @@ static fsal_status_t setxattrs(struct fsal_obj_handle *obj_hdl,
 	int errsv;
 	struct setxattr_arg sxarg;
 	struct gpfs_fsal_obj_handle *myself;
-	struct gpfs_fsal_export *exp = container_of(
-		op_ctx->fsal_export, struct gpfs_fsal_export, export);
+	struct gpfs_fsal_export *exp = container_of(op_ctx->fsal_export,
+						    struct gpfs_fsal_export,
+						    export);
 	int export_fd = exp->export_fd;
 
 	myself = container_of(obj_hdl, struct gpfs_fsal_obj_handle, obj_handle);
@@ -697,8 +702,9 @@ static fsal_status_t removexattrs(struct fsal_obj_handle *obj_hdl,
 	int errsv;
 	struct removexattr_arg rxarg;
 	struct gpfs_fsal_obj_handle *myself;
-	struct gpfs_fsal_export *exp = container_of(
-		op_ctx->fsal_export, struct gpfs_fsal_export, export);
+	struct gpfs_fsal_export *exp = container_of(op_ctx->fsal_export,
+						    struct gpfs_fsal_export,
+						    export);
 	int export_fd = exp->export_fd;
 
 	myself = container_of(obj_hdl, struct gpfs_fsal_obj_handle, obj_handle);
@@ -733,9 +739,11 @@ static fsal_status_t listxattrs(struct fsal_obj_handle *obj_hdl,
 	struct listxattr_arg lxarg;
 	struct gpfs_fsal_obj_handle *myself;
 	component4 *entry = lr_names->xl4_entries;
-	struct gpfs_fsal_export *exp = container_of(
-		op_ctx->fsal_export, struct gpfs_fsal_export, export);
+	struct gpfs_fsal_export *exp = container_of(op_ctx->fsal_export,
+						    struct gpfs_fsal_export,
+						    export);
 	int export_fd = exp->export_fd;
+	fsal_status_t status = { 0, 0 };
 
 	val = (char *)entry + la_maxcount;
 	valstart = val;
@@ -763,15 +771,18 @@ static fsal_status_t listxattrs(struct fsal_obj_handle *obj_hdl,
 		errsv = errno;
 		LogDebug(COMPONENT_FSAL, "LISTXATTRS returned rc %d errsv %d",
 			 rc, errsv);
-		gsh_free(buf);
-		if (errsv == ERANGE)
-			return fsalstat(ERR_FSAL_TOOSMALL, 0);
-		return fsalstat(posix2fsal_error(errsv), errsv);
+		if (errsv == ERANGE) {
+			status = fsalstat(ERR_FSAL_TOOSMALL, ERANGE);
+		} else {
+			status = posix2fsal_status(errsv);
+		}
+		goto out;
 	}
 	if (!lxarg.eof) {
 		errsv = ERR_FSAL_SERVERFAULT;
 		LogCrit(COMPONENT_FSAL, "Unable to get xattr.");
-		return fsalstat(posix2fsal_error(errsv), errsv);
+		status = posix2fsal_status(errsv);
+		goto out;
 	}
 	/* Only return names that the caller can read via getxattr */
 	name = buf;
@@ -791,7 +802,6 @@ static fsal_status_t listxattrs(struct fsal_obj_handle *obj_hdl,
 				     sizeof(component4) >
 			     la_maxcount) ||
 			    ((val - valstart) + (next - name) > la_maxcount)) {
-				gsh_free(buf);
 				*lr_eof = false;
 
 				lr_names->xl4_count = entryCount - *la_cookie;
@@ -801,9 +811,12 @@ static fsal_status_t listxattrs(struct fsal_obj_handle *obj_hdl,
 					     (unsigned long long)*la_cookie,
 					     (next - name), *lr_eof);
 
-				if (lr_names->xl4_count == 0)
-					return fsalstat(ERR_FSAL_TOOSMALL, 0);
-				return fsalstat(ERR_FSAL_NO_ERROR, 0);
+				if (lr_names->xl4_count == 0) {
+					status = fsalstat(ERR_FSAL_TOOSMALL, 0);
+				} else {
+					status = fsalstat(ERR_FSAL_NO_ERROR, 0);
+				}
+				goto out;
 			}
 			entry->utf8string_len = next - name;
 			entry->utf8string_val = val;
@@ -828,12 +841,12 @@ static fsal_status_t listxattrs(struct fsal_obj_handle *obj_hdl,
 	*la_cookie = 0;
 	*lr_eof = true;
 
-	gsh_free(buf);
-
 	LogFullDebug(COMPONENT_FSAL, "out2 cookie %llu eof %d",
 		     (unsigned long long)*la_cookie, *lr_eof);
 
-	return fsalstat(ERR_FSAL_NO_ERROR, 0);
+out:
+	gsh_free(buf);
+	return status;
 }
 
 /*
@@ -1099,8 +1112,9 @@ fsal_status_t gpfs_lookup_path(struct fsal_export *exp_hdl, const char *path,
 	if (FSAL_IS_ERROR(fsal_status))
 		goto xstat_err;
 
-	fsal_status = gpfsfsal_xstat_2_fsal_attributes(
-		&buffxstat, &attributes, acl_buf, gpfs_export->use_acl);
+	fsal_status = gpfsfsal_xstat_2_fsal_attributes(&buffxstat, &attributes,
+						       acl_buf,
+						       gpfs_export->use_acl);
 	LogFullDebug(COMPONENT_FSAL, "fsid=0x%016" PRIx64 ".0x%016" PRIx64,
 		     attributes.fsid.major, attributes.fsid.minor);
 
@@ -1195,8 +1209,9 @@ fsal_status_t gpfs_create_handle(struct fsal_export *exp_hdl,
 	struct fsal_fsid__ fsid;
 	struct fsal_filesystem *fs;
 	struct gpfs_filesystem *gpfs_fs;
-	struct gpfs_fsal_export *exp = container_of(
-		op_ctx->fsal_export, struct gpfs_fsal_export, export);
+	struct gpfs_fsal_export *exp = container_of(op_ctx->fsal_export,
+						    struct gpfs_fsal_export,
+						    export);
 	int export_fd = exp->export_fd;
 
 	*handle = NULL; /* poison it first */
