@@ -48,8 +48,8 @@
 				"SQLite command failed in %s line %i",  \
 				__func__, __LINE__);                    \
 			LogCrit(COMPONENT_FSAL, "%s (%d)",              \
-				(_msg_str_ ? _msg_str_ :                \
-					     sqlite3_errmsg(_p_conn_)), \
+				(_msg_str_ ? _msg_str_                  \
+					   : sqlite3_errmsg(_p_conn_)), \
 				_code_);                                \
 			if (_msg_str_) {                                \
 				sqlite3_free(_msg_str_);                \
@@ -70,8 +70,8 @@
 				"SQLite command failed in %s line %i",  \
 				__func__, __LINE__);                    \
 			LogCrit(COMPONENT_FSAL, "%s (%d)",              \
-				(_msg_str_ ? _msg_str_ :                \
-					     sqlite3_errmsg(_p_conn_)), \
+				(_msg_str_ ? _msg_str_                  \
+					   : sqlite3_errmsg(_p_conn_)), \
 				_code_);                                \
 			if (_msg_str_) {                                \
 				sqlite3_free(_msg_str_);                \
@@ -210,14 +210,14 @@ static db_thread_info_t db_thread[MAX_DB];
 	 (((c) >= 'a') && ((c) <= 'f')))
 
 /* converts an hexa letter */
-#define HEXA2BYTE(c)                                                      \
-	((unsigned char)(((c) >= '0') && ((c) <= '9') ?                   \
-				 ((c) - '0') :                            \
-				 (((c) >= 'A') && ((c) <= 'F') ?          \
-					  ((c) - 'A' + 10) :              \
-					  (((c) >= 'a') && ((c) <= 'f') ? \
-						   ((c) - 'a' + 10) :     \
-						   0))))
+#define HEXA2BYTE(c)                                                        \
+	((unsigned char)(((c) >= '0') && ((c) <= '9')                       \
+				 ? ((c) - '0')                              \
+				 : (((c) >= 'A') && ((c) <= 'F')            \
+					    ? ((c) - 'A' + 10)              \
+					    : (((c) >= 'a') && ((c) <= 'f') \
+						       ? ((c) - 'a' + 10)   \
+						       : 0))))
 
 /**
  * @brief Read a hexadecimal string into memory
@@ -614,7 +614,7 @@ static int dbop_push(flusher_queue_t *p_queue, db_op_item_t *p_op)
 	}
 
 	/* there now some work available */
-	pthread_cond_signal(&p_queue->work_avail_condition);
+	PTHREAD_COND_signal(&p_queue->work_avail_condition);
 
 	PTHREAD_MUTEX_unlock(&p_queue->queues_mutex);
 
@@ -658,7 +658,7 @@ static void *database_worker_thread(void *arg)
 		       p_info->work_queue.lowprio_first == NULL) {
 			to_be_done = NULL;
 			p_info->work_queue.status = IDLE;
-			pthread_cond_signal(
+			PTHREAD_COND_signal(
 				&p_info->work_queue.work_done_condition);
 
 			/* if termination is requested, exit */
@@ -670,7 +670,7 @@ static void *database_worker_thread(void *arg)
 			}
 
 			/* else, wait for something to do */
-			pthread_cond_wait(
+			PTHREAD_COND_wait(
 				&p_info->work_queue.work_avail_condition,
 				&p_info->work_queue.queues_mutex);
 		}
@@ -895,7 +895,7 @@ static void wait_thread_jobs_finished(db_thread_info_t *p_thr_info)
 	while (p_thr_info->work_queue.highprio_first != NULL ||
 	       p_thr_info->work_queue.lowprio_first != NULL ||
 	       p_thr_info->work_queue.status == WORKING)
-		pthread_cond_wait(&p_thr_info->work_queue.work_done_condition,
+		PTHREAD_COND_wait(&p_thr_info->work_queue.work_done_condition,
 				  &p_thr_info->work_queue.queues_mutex);
 
 	PTHREAD_MUTEX_unlock(&p_thr_info->work_queue.queues_mutex);
