@@ -46,18 +46,21 @@ extern __thread struct req_op_context *op_ctx;
 
 /* We define temp variable for op_id so that it has a representative key name
  * generated. */
-#define GSH_AUTO_TRACEPOINT(prov_name, event_name, log_level, format, ...) \
-	do {                                                               \
-		const uint32_t _server_id_ =                               \
-			nfs_param.core_param.unique_server_id;             \
-                                                                           \
-		uint32_t _op_id_ = op_ctx != NULL ? op_ctx->op_id : 0;     \
-		AUTO_TRACEPOINT(                                           \
-			prov_name, event_name, log_level,                  \
-			__FILE__                                           \
-			":" LINE_AS_STRING                                 \
-			" | {fnc} | server_id={} | op_id={} | " format,    \
-			_server_id_, _op_id_, ##__VA_ARGS__);              \
+
+/* clang-format off */
+
+#define GSH_AUTO_TRACEPOINT(prov_name, event_name, log_level, format, ...)  \
+	do {                                                                \
+		const uint32_t _server_id_ =                                \
+			nfs_param.core_param.unique_server_id;              \
+									    \
+		uint32_t _op_id_ = op_ctx != NULL ? op_ctx->op_id : 0;      \
+		AUTO_TRACEPOINT(                                            \
+			prov_name, event_name, log_level,                   \
+			__FILE__                                            \
+			":" LINE_AS_STRING                                  \
+			" | {fnc} | server_id={} | op_id={} | " format,     \
+			_server_id_, _op_id_, ##__VA_ARGS__);               \
 	} while (0)
 
 #define GSH_UNIQUE_AUTO_TRACEPOINT(prov_name, event_name, log_level, format, \
@@ -65,7 +68,7 @@ extern __thread struct req_op_context *op_ctx;
 	do {                                                                 \
 		const uint32_t _server_id_ =                                 \
 			nfs_param.core_param.unique_server_id;               \
-                                                                             \
+									     \
 		uint32_t _op_id_ = op_ctx != NULL ? op_ctx->op_id : 0;       \
 		UNIQUE_AUTO_TRACEPOINT(                                      \
 			prov_name, event_name, log_level,                    \
@@ -75,6 +78,8 @@ extern __thread struct req_op_context *op_ctx;
 			_server_id_, _op_id_, ##__VA_ARGS__);                \
 	} while (0)
 
+/* clang-format on */
+
 #else /* USE_LTTNG */
 
 /* We call the empty function with the variable args to avoid unused variables
@@ -109,6 +114,10 @@ static inline void gsh_empty_function(const char *unused, ...)
 #define TP_BYTE_ARR_TRUNCATED(data, len) \
 	TP_BYTE_ARR((data), MIN((len), TP_CHARS_LIMIT))
 
+#define TP_INT_LIMIT 32 /* Avoid copying too many ints */
+#define TP_INT_ARR_TRUNCATED(data, len) \
+	TP_INT_ARR((data), MIN((len), TP_INT_LIMIT))
+
 #define TP_CINFO_FORMAT "atomic={} before={} after={}"
 #define TP_CINFO_ARGS_EXPAND(cinfo) \
 	(cinfo).atomic, (cinfo).before, (cinfo).after
